@@ -83,7 +83,7 @@ class TronModel(BaseModel):
             self[key_name].value = [value.native for value in reply_key.values]
             self[key_name].key = reply_key
 
-            self.notify(self, self[key_name])
+            self.notify(self)
 
 
 class TronConnection(BaseClient):
@@ -120,8 +120,7 @@ class TronConnection(BaseClient):
                               for model in models}
 
         #: dict: The model and values of each actor being tracked.
-        self.models = {model: TronModel(self.keyword_dicts[model],
-                                        log=self.log)
+        self.models = {model: TronModel(self.keyword_dicts[model])
                        for model in models}
 
         self._parser = None
@@ -186,7 +185,7 @@ class TronConnection(BaseClient):
 
         # The mid must be a 32-bit unsigned number.
         if mid >= 2**32:
-            self._mid = mid = 1
+            self._mid = mid = (mid % 2**32)
 
         command_string = (f'{commander} {mid} {target} {command_string}\n')
 
@@ -230,12 +229,18 @@ class TronConnection(BaseClient):
         while True:
 
             line = await self._client.reader.readline()
+
+            if self._client.reader.at_eof():
+                self.log.error('Client received EOF. This usually means that '
+                               'Tron is not responding. Closing the connection.')
+                self.stop()
+                return
+
             try:
                 line = line.decode()  # Do not strip here or that will cause parsing problems.
                 reply = self.rparser.parse(line)
             except ParseError:
-                if self.log:
-                    self.log.warning(f'Failed parsing reply {line.strip()}.')
+                self.log.warning(f'Failed parsing reply \'{line.strip()}\'.')
                 continue
 
             actor = reply.header.actor
@@ -249,9 +254,8 @@ class TronConnection(BaseClient):
                 try:
                     self.models[actor].parse_reply(reply)
                 except ParseError as ee:
-                    if self.log:
-                        self.log.warning(f'Failed parsing reply {reply!r} '
-                                         f'with error: {ee!s}')
+                    self.log.warning(f'Failed parsing reply {reply!r} '
+                                     f'with error: {ee!s}')
 
             mid = reply.header.commandId
             status = CommandStatus.code_to_status(reply.header.code.lower())
@@ -261,5 +265,3 @@ class TronConnection(BaseClient):
                     self.running_commands[mid].replies.append(reply)
                     command = self.running_commands.pop(mid)
                     command.set_status(status)
-                    if not command.done():
-                        command.set_result(command)
